import type { Ability } from "@proscenium/playbill";
import { html, renderMarkdown } from "#lib";

export async function AbilityCard(ability: Ability): Promise<string> {
  const renderedMarkdown = await renderMarkdown(ability.description);

  const costs: string[] = [];

  if (ability.ap > 0) {
    costs.push(`<li class="ability-cost-ap">${ability.ap} AP</li>`);
  }

  if (ability.hp > 0) {
    costs.push(`<li class="ability-cost-hp">${ability.hp} HP</li>`);
  }

  if (ability.ep > 0) {
    costs.push(`<li class="ability-cost-ep">${ability.ep} EP</li>`);
  }

  const costList =
    costs.length > 0
      ? `<ul class="ability-costs">${costs.join("\n")}</ul>`
      : "";

  const classList = `ability ability-${ability.type}`;

  return html`
    <div class="${classList}" data-component-id="${ability.id}">
      <div class="ability-header">
        <h4>${ability.name}</h4>
        <span class="ability-type">${ability.type}</span>
        <span class="ability-cost-xp">${ability.xp} XP</span>
        ${costList}
      </div>
      <div class="ability-content">
        ${renderedMarkdown}
      </div>
    </div>
  `;
}
