import { html } from "#lib";

interface SectionProps {
  type: string;
  title: string;
  content: string;
  preInfo?: string;
  info?: string;
  componentId?: string;
  leftCornerTag?: string;
  rightCornerTag?: string;
}

export async function Section({
  type,
  title,
  content,
  preInfo = "",
  info = "",
  componentId,
  leftCornerTag = "",
  rightCornerTag = "",
}: SectionProps): Promise<string> {
  const dataTags = componentId ? `data-component-id="${componentId}"` : "";
  return html`
    <section class="section ${type}" ${dataTags}>
      <div class="section-header ${type}-header">
        ${preInfo}
        <h2>${title}</h2>
        ${info}
      </div>
      <div class="section-tag section-tag--left">${leftCornerTag}</div>
      <div class="section-tag section-tag--right">${rightCornerTag}</div>
      <div class="section-content ${type}-content">
        ${content}
      </div>
    </section>
  `;
}
