import type { Method, Playbill } from "@proscenium/playbill";
import { html, renderMarkdown } from "#lib";
import { AbilityCard } from "./ability";
import { Section } from "./base/section";

export async function MethodSection(method: Method, playbill: Playbill) {
  const descriptionHTML = await renderMarkdown(method.description);
  let ranksHTML = "";
  let rankNumber = 1;

  for (const rank of method.abilities) {
    ranksHTML += `<div class="method-rank"><h3>Rank ${rankNumber}</h3><div class="method-rank-content">`;

    for (const ability of rank) {
      const html = await AbilityCard(playbill.abilities[ability]);
      ranksHTML += html;
    }

    ranksHTML += "</div></div>";

    rankNumber++;
  }

  const methodContent = html`
    <div class="method-ranks">
      ${ranksHTML}
    </div>
  `;

  return Section({
    type: "method",
    componentId: method.id,
    title: method.name,
    preInfo: html`<p class="method-curator">${method.curator}'s Method of</p>`,
    info: html`<p class="method-description">${descriptionHTML}</p>`,
    content: methodContent,
  });
}
