import type { Playbill, Species } from "@proscenium/playbill";
import { html, renderMarkdown } from "#lib";
import { AbilityCard } from "./ability";
import { Section } from "./base/section";

export async function SpeciesSection(species: Species, playbill: Playbill) {
  const descriptionHTML = await renderMarkdown(species.description);
  let abilitiesHTML = "";

  for (const ability of species.abilities) {
    abilitiesHTML += await AbilityCard(playbill.abilities[ability]);
  }

  const hpString = species.hp >= 0 ? `+${species.hp}` : `-${species.hp}`;
  const apString = species.ap >= 0 ? `+${species.ap}` : `-${species.ap}`;
  const epString = species.ep >= 0 ? `+${species.ep}` : `-${species.ep}`;

  const hasAbilities = species.abilities.length > 0;

  const abilitySection = hasAbilities
    ? html`
    <div class="species-abilities">
      <h3>Innate Abilities</h3>
      ${abilitiesHTML}
    </div>
  `
    : "";

  const sectionContent = html`
    <div class="species-stats">

      <div class="species-stat-hp">
        <h4 class="hp species-stat-hp-title" title="Health Points">HP</h4>
        <p class="species-stat-hp-value">${hpString}</p>
      </div>

      <div class="species-stat-ap">
        <h4 class="ap species-stat-ap-title" title="Action Points">AP</h4>
        <p class="species-stat-ap-value">${apString}</p>
      </div>

      <div class="species-stat-ep">
        <h4 class="ep species-stat-ep-title" title="Exhaustion Points">EP</h4>
        <p class="species-stat-ep-value">${epString}</p>
      </div>
      
    </div>

    <div class="species-talents">

      <div class="species-talent-muscle">
        <h4 class="species-talent-muscle-title muscle">Muscle</h4>
        <p class="species-talent-muscle-value ${species.muscle}">${species.muscle}</p>
      </div>

      <div class="species-talent-focus">
        <h4 class="species-talent-focus-title focus">Focus</h4>
        <p class="species-talent-focus-value ${species.focus}">${species.focus}</p>
      </div>

      <div class="species-talent-knowledge">
        <h4 class="species-talent-knowledge-title knowledge">Knowledge</h4>
        <p class="species-talent-knowledge-value ${species.knowledge}">${species.knowledge}</p>
      </div>

      <div class="species-talent-charm">
        <h4 class="species-talent-charm-title charm">Charm</h4>
        <p class="species-talent-charm-value ${species.charm}">${species.charm}</p>
      </div>

      <div class="species-talent-cunning">
        <h4 class="species-talent-cunning-title cunning">Cunning</h4>
        <p class="species-talent-cunning-value ${species.cunning}">${species.cunning}</p>
      </div>

      <div class="species-talent-spark">
        <h4 class="species-talent-spark-title spark">Spark</h4>
        <p class="species-talent-spark-value ${species.spark}">${species.spark}</p>
      </div>

    </div>
    <div class="species-content">
      ${descriptionHTML}
    </div>


    ${abilitySection}
  `;

  return Section({
    type: "species",
    componentId: species.id,
    title: species.name,
    content: sectionContent,
    info: "<p>Species</p>",
  });
}
